<?PHP  /* /mod/mlo/lib.php (c)2007, Andreas Forstinger, www.mobilemoodle.org */
/// Library of functions and constants for module mlo

global $CFG;

// define default settings

    if (!isset($CFG->mlo_supported)) { // identifier, used by other modules to check availability
        set_config('mlo_supported', true);
    }
    if (!isset($CFG->mlo_path)) {
        set_config('mlo_path', 'mlo/'); // path where objects are stored (in moodledata)
    }
    if (!isset($CFG->mlo_pass)) {
        set_config('mlo_pass', 'c904db0a2965b4200a7a949561f70040'); // random security hash for
    }
    if (!isset($CFG->mlo_tts_url)) {
        set_config('mlo_tts_url', ''); // optional path to a TTS (text-to-speech) service
    }
    if (!isset($CFG->mlo_use_jnlp_editor)) {
        set_config('mlo_use_jnlp_editor', '0'); // switch between default editor applet and standalone editor
    }
	if (!isset($CFG->mlo_jnlp_editor_url)) {
        set_config('mlo_jnlp_editor_url', 'http://elibera.com/mleeditor/'); // URL where to find offline editor binaries
    }
    if (!isset($CFG->mlo_editor_applet_url)) {
        set_config('mlo_editor_applet_url', 'http://elibera.com/mleeditor/'); // URL where to find editor applet binaries
    }
    
    
/**
 * This function returns the path to the file for the given MLO id
 * @return filepath or false if not exists
 */
function mlo_get_file($id){
    global $CFG;
    if(!$mlo=get_record('mlo','id',$id)){
        return false;
    }

    // make sure directory exists
    $directory = make_upload_directory($CFG->mlo_path);

    $file = $directory . $id . '.zip';

    if(file_exists($file)){
        return $file;
    } else{
        return false;
    }

}

function mlo_add_instance($mlo) {
/// Given an object containing all the necessary data,
/// (defined by the form in mod.html) this function
/// will create a new instance and return the id number
/// of the new instance.

    $mlo->timecreated = $mlo->lastmodified = time();
    $mlo->version = 0;
    $mlo->description = clean_param($mlo->description,PARAM_TEXT);
    return insert_record('mlo', $mlo);
}


function mlo_update_instance($mlo) {
/// Given an object containing all the necessary data,
/// (defined by the form in mod.html) this function
/// will update an existing instance with new data.

    $mlo->lastmodified = time();
    $mlo->id = $mlo->instance;

    return update_record('mlo', $mlo);
}


function mlo_delete_instance($id) {
/// Given an ID of an instance of this module,
/// this function will permanently delete the instance
/// and any data that depends on it.

    if (! $mlo = get_record('mlo', 'id', $id)) {
        return false;
    }

    // delete stored file
    $success = mlo_delete_object($id);

    if($success){
        // delete db entry
        if (! delete_records('mlo', 'id', $mlo->id)) {
            $success = false;
        }
    }

    return $success;
}

/**
 * This function deletes the given tag file
 */
function mlo_delete_object($id){
    global $CFG;
    // first make sure data directory exists
    $directory = make_upload_directory($CFG->mlo_path);
    $file = $directory . $id . '.zip';

    $success = true;
    if(file_exists($file)){
        $success = unlink($file);
    }
    return $success;
}

function mlo_user_outline($course, $user, $mod, $mlo) {
/// Return a small object with summary information about what a
/// user has done with a given particular instance of this module
/// Used for user activity reports.
/// $return->time = the time they did it
/// $return->info = a short text description

    return null;
}

function mlo_user_complete($course, $user, $mod, $mlo) {
/// Print a detailed representation of what a  user has done with
/// a given particular instance of this module, for user activity reports.

    return true;
}

function mlo_print_recent_activity($course, $isteacher, $timestart) {
/// Given a course and a time, this module should find recent activity
/// that has occurred in mlo activities and print it out.
/// Return true if there was output, or false is there was none.

    global $CFG;

    return false;  //  True if anything was printed, otherwise false
}

function mlo_cron () {
/// Function to be run periodically according to the moodle cron
/// This function searches for things that need to be done, such
/// as sending out mail, toggling flags etc ...

    global $CFG;

    return true;
}

function mlo_grades($mloid) {
/// Must return an array of grades for a given instance of this module,
/// indexed by user.  It also returns a maximum allowed grade.
///
///    $return->grades = array of grades;
///    $return->maxgrade = maximum allowed grade;
///
///    return $return;

   return NULL;
}

function mlo_get_participants($mloid) {
//Must return an array of user records (all data) who are participants
//for a given instance of mlo. Must include every user involved
//in the instance, independient of his role (student, teacher, admin...)
//See other modules as example.

    return false;
}

function mlo_scale_used ($mloid,$scaleid) {
//This function returns if a scale is being used by one mlo
//it it has support for grading and scales. Commented code should be
//modified if necessary. See forum, glossary or journal modules
//as reference.

    $return = false;

     return $return;
}

/**
 * Given a course object, this function will clean up anything that
 * would be leftover after all the instances were deleted.
 * @param object $course an object representing the course that is being deleted
 * @param boolean $feedback to specify if the process must output a summary of its work
 * @return boolean
 */
function mlo_delete_course($course,$feedback=true) {

    // get all instances in the given course
    $mlos = get_records('mlo','course',$course->id);

    // manually delete each instance
    foreach ($mlos as $mlo){
        mlo_delete_instance($mlo->id);
    }

    return true;
}


//////////////////////////////////////////////////////////////////////////////////////
/// Any other mlo functions go here.  Each of them must have a name that
/// starts with mlo_


?>